aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/test/regress/pg_regress.sh14
1 files changed, 11 insertions, 3 deletions
diff --git a/src/test/regress/pg_regress.sh b/src/test/regress/pg_regress.sh
index 52dd7623894..a9f0dc423c3 100644
--- a/src/test/regress/pg_regress.sh
+++ b/src/test/regress/pg_regress.sh
@@ -1,5 +1,5 @@
#! /bin/sh
-# $PostgreSQL: pgsql/src/test/regress/pg_regress.sh,v 1.45 2004/06/03 00:25:47 momjian Exp $
+# $PostgreSQL: pgsql/src/test/regress/pg_regress.sh,v 1.46 2004/08/10 22:24:06 tgl Exp $
me=`basename $0`
: ${TMPDIR=/tmp}
@@ -328,8 +328,9 @@ then
# ----------
# Set up shared library paths, needed by psql and pg_encoding
# (if you run multibyte). LD_LIBRARY_PATH covers many platforms,
# feel free to account for others as well.
# ----------
if [ -n "$LD_LIBRARY_PATH" ]; then
@@ -339,6 +340,13 @@ then
fi
export LD_LIBRARY_PATH
+ if [ -n "$DYLD_LIBRARY_PATH" ]; then
+ DYLD_LIBRARY_PATH="$libdir:$DYLD_LIBRARY_PATH"
+ else
+ DYLD_LIBRARY_PATH=$libdir
+ fi
+ export DYLD_LIBRARY_PATH
+
# ----------
# Windows needs shared libraries in PATH. (Only those linked into
# executables, not dlopen'ed ones)
@@ -328,8 +328,9 @@ then
# ----------
# Set up shared library paths, needed by psql and pg_encoding
- # (if you run multibyte). LD_LIBRARY_PATH covers many platforms,
- # feel free to account for others as well.
+ # (if you run multibyte). LD_LIBRARY_PATH covers many platforms.
+ # DYLD_LIBRARY_PATH works on Darwin, and maybe other Mach-based systems.
+ # Feel free to account for others as well.
# ----------
if [ -n "$LD_LIBRARY_PATH" ]; then